<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Export\Export;

use Chill\MainBundle\Export\ExportInterface;
use Chill\MainBundle\Export\FormatterInterface;
use Chill\PersonBundle\Export\Declarations;
use Chill\PersonBundle\Security\Authorization\PersonVoter;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Query;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Security\Core\Role\Role;

class CountPerson implements ExportInterface
{
    /**
     * @var EntityManagerInterface
     */
    protected $entityManager;

    public function __construct(
        EntityManagerInterface $em
    ) {
        $this->entityManager = $em;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        // this export does not add any form
    }

    public function getAllowedFormattersTypes()
    {
        return [FormatterInterface::TYPE_TABULAR];
    }

    public function getDescription()
    {
        return 'Count peoples by various parameters.';
    }

    public function getLabels($key, array $values, $data)
    {
        // the Closure which will be executed by the formatter.
        return function ($value) {
            switch ($value) {
                case '_header':
                    // we have to process specifically the '_header' string,
                    // which will be used by the formatter to show a column title
                    return $this->getTitle();

                default:
                    // for all value, we do not process them and return them
                    // immediatly
                    return $value;
            }
        };
    }

    public function getQueryKeys($data)
    {
        // this array match the result keys in the query. We have only
        // one column.
        return ['export_result'];
    }

    public function getResult($qb, $data)
    {
        return $qb->getQuery()->getResult(Query::HYDRATE_SCALAR);
    }

    public function getTitle()
    {
        return 'Count peoples';
    }

    public function getType()
    {
        return Declarations::PERSON_TYPE;
    }

    public function initiateQuery(array $requiredModifiers, array $acl, array $data = [])
    {
        // we gather all center the user choose.
        $centers = array_map(static function ($el) {
            return $el['center'];
        }, $acl);

        $qb = $this->entityManager->createQueryBuilder();

        $qb->select('COUNT(person.id) AS export_result')
            ->from('ChillPersonBundle:Person', 'person')
            ->join('person.center', 'center')
            ->andWhere('center IN (:authorized_centers)')
            ->setParameter('authorized_centers', $centers);

        return $qb;
    }

    public function requiredRole()
    {
        return new Role(PersonVoter::STATS);
    }

    public function supportsModifiers()
    {
        // explain the export manager which formatters and filters are allowed
        return [Declarations::PERSON_TYPE, Declarations::PERSON_IMPLIED_IN];
    }
}
