<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Class ActivityReason.
 *
 * @ORM\Entity
 * @ORM\Table(name="activityreason")
 * @ORM\HasLifecycleCallbacks
 */
class ActivityReason
{
    /**
     * @var bool
     * @ORM\Column(type="boolean")
     */
    private $active = true;

    /**
     * @var ActivityReasonCategory
     * @ORM\ManyToOne(
     *     targetEntity="Chill\ActivityBundle\Entity\ActivityReasonCategory",
     * inversedBy="reasons")
     */
    private $category;

    /**
     * @var int
     *
     * @ORM\Id
     * @ORM\Column(name="id", type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var array
     * @ORM\Column(type="json")
     */
    private $name;

    /**
     * Get active.
     *
     * @return bool
     */
    public function getActive()
    {
        return $this->active;
    }

    /**
     * Get category.
     *
     * @return ActivityReasonCategory
     */
    public function getCategory()
    {
        return $this->category;
    }

    /**
     * Get id.
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Get name.
     *
     * @param mixed|null $locale
     *
     * @return array | string
     */
    public function getName($locale = null)
    {
        if ($locale) {
            if (isset($this->name[$locale])) {
                return $this->name[$locale];
            }

            foreach ($this->name as $name) {
                if (!empty($name)) {
                    return $name;
                }
            }

            return '';
        }

        return $this->name;
    }

    /**
     * Set active.
     *
     * @param bool $active
     *
     * @return ActivityReason
     */
    public function setActive($active)
    {
        $this->active = $active;

        return $this;
    }

    /**
     * Set category of the reason. If you set to the reason an inactive
     * category, the reason will become inactive.
     *
     * @return ActivityReason
     */
    public function setCategory(ActivityReasonCategory $category)
    {
        if ($this->category !== $category && !$category->getActive()) {
            $this->setActive(false);
        }

        $this->category = $category;

        return $this;
    }

    /**
     * Set name.
     *
     * @param array $name
     *
     * @return ActivityReason
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }
}
