<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Export\Aggregator;

use Chill\ActivityBundle\Security\Authorization\ActivityStatsVoter;
use Chill\MainBundle\Export\AggregatorInterface;
use Chill\MainBundle\Repository\UserRepository;
use Closure;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Security\Core\Role\Role;

class ActivityUserAggregator implements AggregatorInterface
{
    public const KEY = 'activity_user_id';

    private UserRepository $userRepository;

    public function __construct(
        UserRepository $userRepository
    ) {
        $this->userRepository = $userRepository;
    }

    public function addRole()
    {
        return new Role(ActivityStatsVoter::STATS);
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        // add select element
        $qb->addSelect(sprintf('IDENTITY(activity.user) AS %s', self::KEY));

        // add the "group by" part
        $qb->addGroupBy(self::KEY);
    }

    public function applyOn(): string
    {
        return 'activity';
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        // nothing to add
    }

    public function getLabels($key, $values, $data): Closure
    {
        // preload users at once
        $this->userRepository->findBy(['id' => $values]);

        return function ($value) {
            if ('_header' === $value) {
                return 'activity user';
            }

            return $this->userRepository->find($value)->getUsername();
        };
    }

    public function getQueryKeys($data)
    {
        return [self::KEY];
    }

    public function getTitle(): string
    {
        return 'Aggregate by activity user';
    }
}
