<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Export\Export;

use Chill\ActivityBundle\Repository\ActivityRepository;
use Chill\ActivityBundle\Security\Authorization\ActivityStatsVoter;
use Chill\MainBundle\Export\ExportInterface;
use Chill\MainBundle\Export\FormatterInterface;
use Doctrine\ORM\Query;
use LogicException;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Security\Core\Role\Role;

class CountActivity implements ExportInterface
{
    protected ActivityRepository $activityRepository;

    public function __construct(
        ActivityRepository $activityRepository
    ) {
        $this->activityRepository = $activityRepository;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
    }

    public function getAllowedFormattersTypes()
    {
        return [FormatterInterface::TYPE_TABULAR];
    }

    public function getDescription()
    {
        return 'Count activities by various parameters.';
    }

    public function getLabels($key, array $values, $data)
    {
        if ('export_count_activity' !== $key) {
            throw new LogicException("the key {$key} is not used by this export");
        }

        return static fn ($value) => '_header' === $value ? 'Number of activities' : $value;
    }

    public function getQueryKeys($data)
    {
        return ['export_count_activity'];
    }

    public function getResult($qb, $data)
    {
        return $qb->getQuery()->getResult(Query::HYDRATE_SCALAR);
    }

    public function getTitle()
    {
        return 'Count activities';
    }

    public function getType()
    {
        return 'activity';
    }

    public function initiateQuery(array $requiredModifiers, array $acl, array $data = [])
    {
        $centers = array_map(static fn ($el) => $el['center'], $acl);

        $qb = $this
            ->activityRepository
            ->createQueryBuilder('activity')
            ->select('COUNT(activity.id) as export_count_activity')
            ->join('activity.person', 'person');

        $qb
            ->where($qb->expr()->in('person.center', ':centers'))
            ->setParameter('centers', $centers);

        return $qb;
    }

    public function requiredRole()
    {
        return new Role(ActivityStatsVoter::STATS);
    }

    public function supportsModifiers()
    {
        return ['person', 'activity'];
    }
}
