<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Form\Type;

use Chill\ActivityBundle\Entity\ActivityReason;
use Chill\ActivityBundle\Templating\Entity\ActivityReasonRender;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Doctrine\ORM\EntityRepository;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * FormType to choose amongst activity reasons.
 */
class TranslatableActivityReason extends AbstractType
{
    /**
     * @var ActivityReasonRender
     */
    protected $reasonRender;

    /**
     * @var TranslatableStringHelper
     */
    protected $translatableStringHelper;

    public function __construct(
        TranslatableStringHelper $translatableStringHelper,
        ActivityReasonRender $reasonRender
    ) {
        $this->translatableStringHelper = $translatableStringHelper;
        $this->reasonRender = $reasonRender;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(
            [
                'class' => 'ChillActivityBundle:ActivityReason',
                'choice_label' => function (ActivityReason $choice) {
                    return $this->reasonRender->renderString($choice, []);
                },
                'group_by' => function (ActivityReason $choice): ?string {
                    if (null !== $category = $choice->getCategory()) {
                        return $this->translatableStringHelper->localize($category->getName());
                    }

                    return null;
                },
                'query_builder' => static function (EntityRepository $er) {
                    return $er->createQueryBuilder('r')
                        ->where('r.active = true');
                },
                'attr' => ['class' => ' select2 '],
            ]
        );
    }

    public function getBlockPrefix()
    {
        return 'translatable_activity_reason';
    }

    public function getParent()
    {
        return EntityType::class;
    }
}
