<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Form\Type;

use Doctrine\ORM\EntityRepository;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * Description of TranslatableActivityReasonCategory.
 */
class TranslatableActivityReasonCategory extends AbstractType
{
    /**
     * @var RequestStack
     */
    private $requestStack;

    public function __construct(RequestStack $requestStack)
    {
        $this->requestStack = $requestStack;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $locale = $this->requestStack->getCurrentRequest()->getLocale();
        $resolver->setDefaults(
            [
                'class' => 'ChillActivityBundle:ActivityReasonCategory',
                'choice_label' => 'name[' . $locale . ']',
                'query_builder' => static function (EntityRepository $er) {
                    return $er->createQueryBuilder('c')
                        ->where('c.active = true');
                },
            ]
        );
    }

    public function getBlockPrefix()
    {
        return 'translatable_activity_reason_category';
    }

    public function getParent()
    {
        return EntityType::class;
    }
}
