<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Form\Type;

use Chill\ActivityBundle\Entity\ActivityType;
use Chill\ActivityBundle\Repository\ActivityTypeRepository;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class TranslatableActivityType extends AbstractType
{
    protected ActivityTypeRepository $activityTypeRepository;

    protected TranslatableStringHelperInterface $translatableStringHelper;

    public function __construct(
        TranslatableStringHelperInterface $helper,
        ActivityTypeRepository $activityTypeRepository
    ) {
        $this->translatableStringHelper = $helper;
        $this->activityTypeRepository = $activityTypeRepository;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        /** @var QueryBuilder $qb */
        $qb = $options['query_builder'];

        if (true === $options['active_only']) {
            $qb->where($qb->expr()->eq('at.active', ':active'));
            $qb->setParameter('active', true, Types::BOOLEAN);
        }
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(
            [
                'class' => ActivityType::class,
                'active_only' => true,
                'query_builder' => $this->activityTypeRepository
                    ->createQueryBuilder('at'),
                'choice_label' => function (ActivityType $type) {
                    return $this->translatableStringHelper->localize($type->getName());
                },
            ]
        );
    }

    public function getBlockPrefix()
    {
        return 'translatable_activity_type';
    }

    public function getParent()
    {
        return EntityType::class;
    }
}
