<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Repository;

use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\PersonBundle\Entity\Person;

interface ActivityACLAwareRepositoryInterface
{
    /**
     * @return Activity[]|array
     */
    public function findByAccompanyingPeriod(AccompanyingPeriod $period, string $role, ?int $start = 0, ?int $limit = 1000, ?array $orderBy = []): array;

    /**
     * Return a list of activities, simplified as array (not object).
     *
     * The aim of this method is to get a long list of activities and keep performance.
     *
     * @return array an array of array, each item representing an activity
     */
    public function findByAccompanyingPeriodSimplified(AccompanyingPeriod $period, ?int $limit = 1000): array;

    /**
     * @return Activity[]|array
     */
    public function findByPerson(Person $person, string $role, ?int $start = 0, ?int $limit = 1000, ?array $orderBy = []): array;
}
