<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Tests\Export\Aggregator;

use Chill\MainBundle\Test\Export\AbstractAggregatorTest;

/**
 * Add tests for ActivityReasonAggregator.
 *
 * @internal
 * @coversNothing
 */
final class ActivityReasonAggregatorTest extends AbstractAggregatorTest
{
    /**
     * @var \Chill\ActivityBundle\Export\Aggregator\ActivityReasonAggregator
     */
    private $aggregator;

    protected function setUp(): void
    {
        self::bootKernel();

        $container = self::$kernel->getContainer();

        $this->aggregator = $container->get('chill.activity.export.reason_aggregator');

        // add a fake request with a default locale (used in translatable string)
        $prophet = new \Prophecy\Prophet();
        $request = $prophet->prophesize();
        $request->willExtend(\Symfony\Component\HttpFoundation\Request::class);
        $request->getLocale()->willReturn('fr');

        $container->get('request_stack')
            ->push($request->reveal());
    }

    public function getAggregator()
    {
        return $this->aggregator;
    }

    public function getFormData()
    {
        return [
            ['level' => 'reasons'],
            ['level' => 'categories'],
        ];
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$kernel->getContainer()
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'reasons'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'reasons')
                ->join('reasons.category', 'category'),
        ];
    }
}
