<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Tests\Export\Export;

use Chill\MainBundle\Test\Export\AbstractExportTest;

/**
 * @internal
 * @coversNothing
 */
final class ListActivityTest extends AbstractExportTest
{
    /**
     * @var \Chill\ActivityBundle\Export\Export\ListActivity
     */
    private $export;

    protected function setUp(): void
    {
        self::bootKernel();

        /** @var \Symfony\Component\DependencyInjection\ContainerInterface $container */
        $container = self::$kernel->getContainer();

        $this->export = $container->get('chill.activity.export.list_activity');

        // add a fake request with a default locale (used in translatable string)
        $prophet = new \Prophecy\Prophet();
        $request = $prophet->prophesize();
        $request->willExtend(\Symfony\Component\HttpFoundation\Request::class);
        $request->getLocale()->willReturn('fr');

        $container->get('request_stack')
            ->push($request->reveal());
    }

    public function getExport()
    {
        return $this->export;
    }

    public function getFormData()
    {
        return [
            ['fields' => [
                'id',
                'date',
                'durationTime',
                'attendee',
                'user_username',
                'circle_name',
                'type_name',
                'person_firstname',
                'person_lastname',
                'person_id',
            ]],
            ['fields' => [
                'id',
                'list_reasons',
            ]],
        ];
    }

    public function getModifiersCombination()
    {
        return [
            ['activity'],
            ['activity', 'person'],
        ];
    }
}
