<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ActivityBundle\Tests\Export\Filter;

use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * @internal
 * @coversNothing
 */
final class ActivityReasonFilterTest extends AbstractFilterTest
{
    /**
     * @var \Chill\PersonBundle\Export\Filter\GenderFilter
     */
    private $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $container = self::$kernel->getContainer();

        $this->filter = $container->get('chill.activity.export.reason_filter');

        // add a fake request with a default locale (used in translatable string)
        $prophet = new \Prophecy\Prophet();
        $request = $prophet->prophesize();
        $request->willExtend(\Symfony\Component\HttpFoundation\Request::class);
        $request->getLocale()->willReturn('fr');

        $container->get('request_stack')
            ->push($request->reveal());
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$kernel->getContainer()
            ->get('doctrine.orm.entity_manager');

        $reasons = $em->createQuery('SELECT reason '
                . 'FROM ChillActivityBundle:ActivityReason reason')
            ->getResult();

        // generate an array of 5 different combination of results
        for ($i = 0; 5 > $i; ++$i) {
            $r[] = ['reasons' => new ArrayCollection(array_splice($reasons, ($i + 1) * -1))];
        }

        return $r;
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$kernel->getContainer()
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'reasons'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'reasons')
                ->join('reasons.category', 'category'),
        ];
    }
}
