<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\AsideActivityBundle\Menu;

use Knp\Menu\MenuItem;
use Symfony\Component\Security\Core\Security;

use function in_array;

final class AdminMenuBuilder implements \Chill\MainBundle\Routing\LocalMenuBuilderInterface
{
    private Security $security;

    public function __construct(Security $security)
    {
        $this->security = $security;
    }

    public function buildMenu($menuId, MenuItem $menu, array $parameters)
    {
        // all the entries below must have ROLE_ADMIN permissions
        if (!$this->security->isGranted('ROLE_ADMIN')) {
            return;
        }

        if (in_array($menuId, ['admin_index', 'admin_section'], true)) {
            $menu->addChild('Aside activities', [
                'route' => 'chill_crud_aside_activity_category_index',
            ])
                ->setExtras([
                    'order' => 900,
                    'explain' => 'Aside activity type configuration',
                ]);
        } else {
            $menu
                ->addChild('Aside activity categories', [
                    'route' => 'chill_crud_aside_activity_category_index',
                ])
                ->setExtras([
                    'order' => '50',
                ]);
        }
    }

    public static function getMenuIds(): array
    {
        return ['admin_index', 'admin_section', 'admin_aside_activity'];
    }
}
