<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\AsideActivityBundle\Tests\Controller;

use Chill\AsideActivityBundle\Entity\AsideActivity;
use Chill\MainBundle\Test\PrepareClientTrait;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;
use function array_pop;
use function shuffle;

/**
 * @internal
 * @coversNothing
 */
final class AsideActivityControllerTest extends WebTestCase
{
    use PrepareClientTrait;

    protected function setUp(): void
    {
        parent::setUp();
        self::bootKernel();
        $this->client = $this->getClientAuthenticated();
    }

    public function generateAsideActivityId()
    {
        self::bootKernel();

        $qb = self::$container->get(EntityManagerInterface::class)
            ->createQueryBuilder();

        $asideActivityIds = $qb
            ->select('DISTINCT asideactivity.id')
            ->from(AsideActivity::class, 'asideactivity')
            ->innerJoin('asideactivity.agent', 'agent')
            ->where($qb->expr()->eq('agent.username', ':center_name'))
            ->setParameter('center_name', 'center a_social')
            ->setMaxResults(100)
            ->getQuery()
            ->getResult();

        shuffle($asideActivityIds);

        yield [array_pop($asideActivityIds)['id']];

        yield [array_pop($asideActivityIds)['id']];

        yield [array_pop($asideActivityIds)['id']];
    }

    /**
     * @dataProvider generateAsideActivityId
     */
    public function testEditWithoutUsers(int $asideActivityId)
    {
        $this->client->request('GET', "/fr/asideactivity/{$asideActivityId}/edit");

        $this->assertEquals(200, $this->client->getResponse()->getStatusCode());
    }

    public function testIndexWithoutUsers()
    {
        $this->client->request('GET', '/fr/asideactivity');

        $this->assertEquals(200, $this->client->getResponse()->getStatusCode());
    }

    public function testNewWithoutUsers()
    {
        $this->client->request('GET', '/fr/asideactivity/new');

        $this->assertEquals(200, $this->client->getResponse()->getStatusCode());
    }
}
