<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\BudgetBundle\Config;

class ConfigRepository
{
    /**
     * @var array
     */
    protected $charges;

    /**
     * @var array
     */
    protected $resources;

    public function __construct($resources, $charges)
    {
        $this->resources = $resources;
        $this->charges = $charges;
    }

    public function getChargesKeys(): array
    {
        return array_map(static function ($element) { return $element['key']; }, $this->charges);
    }

    /**
     * @return array where keys are the resource'key and label the ressource label
     */
    public function getChargesLabels()
    {
        $charges = [];

        foreach ($this->charges as $definition) {
            $charges[$definition['key']] = $this->normalizeLabel($definition['labels']);
        }

        return $charges;
    }

    public function getResourcesKeys(): array
    {
        return array_map(static function ($element) { return $element['key']; }, $this->resources);
    }

    /**
     * @return array where keys are the resource'key and label the ressource label
     */
    public function getResourcesLabels()
    {
        $resources = [];

        foreach ($this->resources as $definition) {
            $resources[$definition['key']] = $this->normalizeLabel($definition['labels']);
        }

        return $resources;
    }

    private function normalizeLabel($labels)
    {
        $normalizedLabels = [];

        foreach ($labels as $labelDefinition) {
            $normalizedLabels[$labelDefinition['lang']] = $labelDefinition['label'];
        }

        return $normalizedLabels;
    }
}
