<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\BudgetBundle\Menu;

use Chill\BudgetBundle\Security\Authorization\BudgetElementVoter;
use Chill\MainBundle\Routing\LocalMenuBuilderInterface;
use Chill\PersonBundle\Entity\Household\Household;
use Knp\Menu\MenuItem;
use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;
use Symfony\Contracts\Translation\TranslatorInterface;

class HouseholdMenuBuilder implements LocalMenuBuilderInterface
{
    protected AuthorizationCheckerInterface $authorizationChecker;

    protected TranslatorInterface $translator;

    public function __construct(
        AuthorizationCheckerInterface $authorizationChecker,
        TranslatorInterface $translator
    ) {
        $this->authorizationChecker = $authorizationChecker;
        $this->translator = $translator;
    }

    public function buildMenu($menuId, MenuItem $menu, array $parameters)
    {
        /** @var Household $household */
        $household = $parameters['household'];

        // if ($this->authorizationChecker->isGranted(BudgetElementVoter::SHOW, $household)) {
        $menu->addChild($this->translator->trans('household.Budget'), [
            'route' => 'chill_budget_elements_household_index',
            'routeParameters' => [
                'id' => $household->getId(),
            ], ])
            ->setExtras(['order' => 19]);
        // }
    }

    public static function getMenuIds(): array
    {
        return ['household'];
    }
}
