<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\BudgetBundle\Security\Authorization;

use Chill\BudgetBundle\Entity\AbstractElement;
use Chill\MainBundle\Security\Authorization\AbstractChillVoter;
use Chill\MainBundle\Security\Authorization\VoterHelperFactoryInterface;
use Chill\MainBundle\Security\Authorization\VoterHelperInterface;
use Chill\MainBundle\Security\ProvideRoleHierarchyInterface;
use Chill\PersonBundle\Entity\Household\Household;
use Chill\PersonBundle\Entity\Person;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;

use function in_array;

class BudgetElementVoter extends AbstractChillVoter implements ProvideRoleHierarchyInterface
{
    public const CREATE = 'CHILL_BUDGET_ELEMENT_CREATE';

    public const DELETE = 'CHILL_BUDGET_ELEMENT_DELETE';

    public const ROLES = [
        self::CREATE,
        self::DELETE,
        self::SEE,
        self::UPDATE,
    ];

    public const SEE = 'CHILL_BUDGET_ELEMENT_SEE';

    public const UPDATE = 'CHILL_BUDGET_ELEMENT_UPDATE';

    protected VoterHelperInterface $voter;

    public function __construct(VoterHelperFactoryInterface $voterFactory)
    {
        $this->voter = $voterFactory
            ->generate(self::class)
            ->addCheckFor(AbstractElement::class, self::ROLES)
            ->addCheckFor(Person::class, [self::CREATE, self::SEE])
            ->addCheckFor(Household::class, [self::CREATE, self::SEE])
            ->build();
    }

    public function getRoles(): array
    {
        return self::ROLES;
    }

    public function getRolesWithHierarchy(): array
    {
        return ['Budget elements' => self::ROLES];
    }

    public function getRolesWithoutScope(): array
    {
        return self::ROLES;
    }

    protected function supports($attribute, $subject)
    {
        return (in_array($attribute, self::ROLES, true) && $subject instanceof AbstractElement)
                || (($subject instanceof Person || $subject instanceof Household) && in_array($attribute, [self::SEE, self::CREATE], true));
    }

    protected function voteOnAttribute($attribute, $subject, TokenInterface $token)
    {
        return $this->voter->voteOnAttribute($attribute, $subject, $token);
    }
}
