<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\CustomFieldsBundle\CustomFields;

use Chill\CustomFieldsBundle\Entity\CustomField;
use Chill\CustomFieldsBundle\Form\Type\CustomFieldsTitleType;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Symfony\Bundle\TwigBundle\TwigEngine;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\HttpFoundation\RequestStack;

class CustomFieldTitle extends AbstractCustomField
{
    public const TYPE = 'type';

    public const TYPE_SUBTITLE = 'subtitle';

    public const TYPE_TITLE = 'title';

    private $requestStack;

    /**
     * @var TwigEngine
     */
    private $templating;

    /**
     * @var TranslatableStringHelper Helper that find the string in current locale from an array of translation
     */
    private $translatableStringHelper;

    public function __construct(
        RequestStack $requestStack,
        TwigEngine $templating,
        TranslatableStringHelper $translatableStringHelper
    ) {
        $this->requestStack = $requestStack;
        $this->templating = $templating;
        $this->translatableStringHelper = $translatableStringHelper;
    }

    public function buildForm(FormBuilderInterface $builder, CustomField $customField)
    {
        $builder->add($customField->getSlug(), CustomFieldsTitleType::class, [
            'label' => false,
            'attr' => [
                'class' => 'cf-title',
                'title' => $this->translatableStringHelper->localize($customField->getName()),
                self::TYPE => $customField->getOptions()[self::TYPE],
            ],
        ]);
    }

    public function buildOptionsForm(FormBuilderInterface $builder)
    {
        return $builder->add(
            self::TYPE,
            ChoiceType::class,
            [
                'choices' => [
                    'Main title' => self::TYPE_TITLE,
                    'Subtitle' => self::TYPE_SUBTITLE,
                ],
                'label' => 'Title level',
            ]
        );
    }

    public function deserialize($serialized, CustomField $customField)
    {
        return $serialized;
    }

    public function getName()
    {
        return 'Title';
    }

    public function isEmptyValue($value, CustomField $customField)
    {
        return false;
    }

    public function render($value, CustomField $customField, $documentType = 'html')
    {
        return $this->templating
            ->render(
                'ChillCustomFieldsBundle:CustomFieldsRendering:title.html.twig',
                [
                    'title' => $customField->getName(),
                    'type' => $customField->getOptions()[self::TYPE],
                ]
            );
    }

    public function serialize($value, CustomField $customField)
    {
        return $value;
    }
}
