<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\CustomFieldsBundle\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * CustomFieldGroup.
 *
 * @ORM\Entity
 * @ORM\Table(name="customfieldsgroup")
 */
class CustomFieldsGroup
{
    /**
     * The custom fields of the group that are active.
     * This variable if null, if this informations has not been computed.
     *
     * @var array|null
     */
    private $activeCustomFields;

    /**
     * The custom fields of the group.
     * The custom fields are asc-ordered regarding to their property "ordering".
     *
     * @var Collection
     *
     * @ORM\OneToMany(
     *     targetEntity="Chill\CustomFieldsBundle\Entity\CustomField",
     * mappedBy="customFieldGroup")
     * @ORM\OrderBy({"ordering": "ASC"})
     */
    private $customFields;

    /**
     * @var string
     *
     * @ORM\Column(type="string", length=255)
     */
    private $entity;

    /**
     * @var int
     *
     * @ORM\Id
     * @ORM\Column(name="id", type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var array
     *
     * @ORM\Column(type="json")
     */
    private $name;

    /**
     * @var array
     *
     * @ORM\Column(type="json")
     */
    private $options = [];

    /**
     * CustomFieldsGroup constructor.
     */
    public function __construct()
    {
        $this->customFields = new ArrayCollection();
    }

    /**
     * Add customField.
     *
     * @return CustomFieldsGroup
     */
    public function addCustomField(CustomField $customField)
    {
        $this->customFields[] = $customField;

        return $this;
    }

    /**
     * Get all the custom.
     *
     * @return Collection
     */
    public function getActiveCustomFields()
    {
        if (null === $this->activeCustomFields) {
            $this->activeCustomFields = [];

            foreach ($this->customFields as $cf) {
                if ($cf->isActive()) {
                    $this->activeCustomFields[] = $cf;
                }
            }
        }

        return $this->activeCustomFields;
    }

    /**
     * @return Collection
     */
    public function getCustomFields()
    {
        return $this->customFields;
    }

    /**
     * Get entity.
     *
     * @return string
     */
    public function getEntity()
    {
        return $this->entity;
    }

    /**
     * Get id.
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Get name.
     *
     * @param mixed|null $language
     *
     * @return array
     */
    public function getName($language = null)
    {
        //TODO set this in a service, PLUS twig function
        if ($language) {
            if (isset($this->name[$language])) {
                return $this->name[$language];
            }

            foreach ($this->name as $name) {
                if (!empty($name)) {
                    return $name;
                }
            }

            return '';
        }

        return $this->name;
    }

    /**
     * get options array.
     *
     * @return array
     */
    public function getOptions()
    {
        return $this->options;
    }

    /**
     * Remove customField.
     */
    public function removeCustomField(CustomField $customField)
    {
        $this->customFields->removeElement($customField);
    }

    /**
     * Set entity.
     *
     * @param string $entity
     *
     * @return CustomFieldsGroup
     */
    public function setEntity($entity)
    {
        $this->entity = $entity;

        return $this;
    }

    /**
     * Set name.
     *
     * @param array $name
     *
     * @return CustomFieldsGroup
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * set options array.
     *
     * @return CustomFieldsGroup
     */
    public function setOptions(array $options)
    {
        $this->options = $options;

        return $this;
    }
}
