<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\DocGeneratorBundle\Menu;

use Chill\MainBundle\Routing\LocalMenuBuilderInterface;
use Knp\Menu\MenuItem;
use Symfony\Component\Security\Core\Security;
use Symfony\Contracts\Translation\TranslatorInterface;

use function in_array;

class AdminMenuBuilder implements LocalMenuBuilderInterface
{
    private Security $security;

    private TranslatorInterface $translator;

    public function __construct(TranslatorInterface $translator, Security $security)
    {
        $this->translator = $translator;
        $this->security = $security;
    }

    public function buildMenu($menuId, MenuItem $menu, array $parameters)
    {
        if ($this->security->isGranted('ROLE_ADMIN')) {
            if (in_array($menuId, ['admin_index', 'admin_section'], true)) {
                $menu->addChild($this->translator->trans('docgen.Document generation'), [
                    'route' => 'chill_crud_docgen_template_index',
                ])->setExtras([
                    'order' => 350,
                    'explain' => 'docgen.Manage templates and document generation',
                ]);
            }
        }
    }

    public static function getMenuIds(): array
    {
        return ['admin_index', 'admin_section', 'docgen_admin'];
    }
}
