<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\EventBundle\Form;

use Chill\EventBundle\Form\Type\PickEventTypeType;
use Chill\MainBundle\Entity\Center;
use Chill\MainBundle\Form\Type\ChillDateTimeType;
use Chill\MainBundle\Form\Type\ScopePickerType;
use Chill\MainBundle\Form\Type\UserPickerType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Role\Role;

class EventType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('name')
            ->add('date', ChillDateTimeType::class, [
                'required' => true,
            ])
            ->add('circle', ScopePickerType::class, [
                'center' => $options['center'],
                'role' => $options['role'],
            ])
            ->add('type', PickEventTypeType::class, [
                'placeholder' => 'Pick a type of event',
                'attr' => [
                    'class' => '',
                ],
            ])
            ->add('moderator', UserPickerType::class, [
                'center' => $options['center'],
                'role' => $options['role'],
                'placeholder' => 'Pick a moderator',
                'attr' => [
                    'class' => '',
                ],
                'required' => false,
            ]);
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => 'Chill\EventBundle\Entity\Event',
        ]);
        $resolver
            ->setRequired(['center', 'role'])
            ->setAllowedTypes('center', Center::class)
            ->setAllowedTypes('role', Role::class);
    }

    /**
     * @return string
     */
    public function getName()
    {
        return 'chill_eventbundle_event';
    }
}
