<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\EventBundle\Repository;

use Doctrine\ORM\EntityRepository;

/**
 * Class ParticipationRepository.
 */
class ParticipationRepository extends EntityRepository
{
    /**
     * Count number of participations per person.
     *
     * @param $person_id
     *
     * @throws \Doctrine\ORM\NonUniqueResultException
     *
     * @return mixed
     */
    public function countByPerson($person_id)
    {
        return $this->createQueryBuilder('p')
            ->select('COUNT (p.id)')
            ->where('p.id = :person_id')
            ->setParameter(':person_id', $person_id)
            ->getQuery()
            ->getSingleScalarResult();
    }

    /**
     * Return paginated participations for a person and in reachables circles.
     *
     * @param $person_id
     * @param $reachablesCircles
     * @param $first
     * @param $max
     *
     * @return mixed
     */
    public function findByPersonInCircle($person_id, $reachablesCircles, $first, $max)
    {
        return $this->createQueryBuilder('p')
            ->join('p.event', 'e')
            ->where('p.person = :person_id')
            ->andWhere('e.circle IN (:reachable_circles)')
            ->orderBy('e.date', 'ASC')
            ->setParameters([
                ':person_id' => $person_id,
                ':reachable_circles' => $reachablesCircles,
            ])
            ->setFirstResult($first)
            ->setMaxResults($max)
            ->getQuery()
            ->getResult();
    }
}
