<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 * @ORM\Table(name="group_centers")
 * @ORM\Cache(usage="NONSTRICT_READ_WRITE", region="acl_cache_region")
 */
class GroupCenter
{
    /**
     * @var Center
     *
     * @ORM\ManyToOne(
     *     targetEntity="Chill\MainBundle\Entity\Center",
     *     inversedBy="groupCenters"
     * )
     * @ORM\Cache(usage="NONSTRICT_READ_WRITE")
     */
    private $center;

    /**
     * @var int
     *
     * @ORM\Id
     * @ORM\Column(name="id", type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var PermissionsGroup
     *
     * @ORM\ManyToOne(
     *     targetEntity="Chill\MainBundle\Entity\PermissionsGroup",
     * inversedBy="groupCenters")
     * @ORM\Cache(usage="NONSTRICT_READ_WRITE")
     */
    private $permissionsGroup;

    /**
     * @var Collection
     *
     * @ORM\ManyToMany(
     *     targetEntity="Chill\MainBundle\Entity\User",
     *     mappedBy="groupCenters"
     * )
     */
    private $users;

    /**
     * GroupCenter constructor.
     */
    public function __construct()
    {
        $this->permissionsGroup = new ArrayCollection();
        $this->users = new ArrayCollection();
    }

    /**
     * @return Center
     */
    public function getCenter()
    {
        return $this->center;
    }

    /**
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @return PermissionGroup
     */
    public function getPermissionsGroup()
    {
        return $this->permissionsGroup;
    }

    /**
     * @return ArrayCollection|Collection
     */
    public function getUsers()
    {
        return $this->users;
    }

    /**
     * @return \Chill\MainBundle\Entity\GroupCenter
     */
    public function setCenter(Center $center)
    {
        $this->center = $center;

        return $this;
    }

    /**
     * @return \Chill\MainBundle\Entity\GroupCenter
     */
    public function setPermissionsGroup(PermissionsGroup $permissionsGroup)
    {
        $this->permissionsGroup = $permissionsGroup;

        return $this;
    }
}
