<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Form\Type\DataTransformer;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Form\DataTransformerInterface;

class MultipleObjectsToIdTransformer implements DataTransformerInterface
{
    private ?string $class;

    private EntityManagerInterface $em;

    public function __construct(EntityManagerInterface $em, ?string $class = null)
    {
        $this->em = $em;
        $this->class = $class;
    }

    /**
     * Transforms a string (id) to an object (item).
     *
     * @param mixed $array
     *
     * @return ArrayCollection
     */
    public function reverseTransform($array)
    {
        $ret = new ArrayCollection();

        foreach ($array as $el) {
            $ret->add(
                $this->em
                    ->getRepository($this->class)
                    ->find($el)
            );
        }

        return $ret;
    }

    /**
     * Transforms an object (use) to a string (id).
     *
     * @param array $array
     *
     * @return ArrayCollection
     */
    public function transform($array)
    {
        $ret = [];

        foreach ($array as $el) {
            $ret[] = ($el->getId());
        }

        return $ret;
    }
}
