<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Form\Type\DataTransformer;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Form\DataTransformerInterface;
use Symfony\Component\Form\Exception\TransformationFailedException;

class ObjectToIdTransformer implements DataTransformerInterface
{
    private ?string $class;

    private EntityManagerInterface $em;

    public function __construct(EntityManagerInterface $em, ?string $class = null)
    {
        $this->em = $em;
        $this->class = $class;
    }

    /**
     * Transforms a string (id) to an object.
     *
     * @param  string $id
     *
     * @throws TransformationFailedException if object is not found.
     *
     * @return object|null
     */
    public function reverseTransform($id)
    {
        if (null === $id) {
            return null;
        }

        $object = $this->em
            ->getRepository($this->class)
            ->find($id);

        if (null === $object) {
            throw new TransformationFailedException();
        }

        return $object;
    }

    /**
     * Transforms an object to a string (id).
     *
     * @param mixed $object
     *
     * @return string
     */
    public function transform($object)
    {
        if (null === $object) {
            return '';
        }

        return $object->getId();
    }
}
