<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Form\Type\Export;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class FilterType extends AbstractType
{
    public const ENABLED_FIELD = 'enabled';

    public function __construct()
    {
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $exportManager = $options['export_manager'];
        $filter = $exportManager->getFilter($options['filter_alias']);

        $builder
            ->add(self::ENABLED_FIELD, CheckboxType::class, [
                'value' => true,
                'data' => false,
                'required' => false,
            ]);

        $filterFormBuilder = $builder->create('form', FormType::class, [
            'compound' => true,
            'error_bubbling' => false,
            'required' => false,
        ]);
        $filter->buildForm($filterFormBuilder);

        $builder->add($filterFormBuilder);
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setRequired('filter_alias')
            ->setRequired('export_manager')
            ->setDefault('compound', true)
            ->setDefault('error_bubbling', false);
    }
}
