<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Form\Type\Listing;

use Chill\MainBundle\Templating\Listing\FilterOrderHelper;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\HiddenType;
use Symfony\Component\Form\Extension\Core\Type\SearchType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\Form\FormView;
use Symfony\Component\HttpFoundation\RequestStack;

use function array_combine;
use function array_map;
use function count;

final class FilterOrderType extends \Symfony\Component\Form\AbstractType
{
    private RequestStack $requestStack;

    public function __construct(RequestStack $requestStack)
    {
        $this->requestStack = $requestStack;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        /** @var FilterOrderHelper $helper */
        $helper = $options['helper'];

        if ($helper->hasSearchBox()) {
            $builder->add('q', SearchType::class, [
                'label' => false,
                'required' => false,
            ]);
        }

        $checkboxesBuilder = $builder->create('checkboxes', null, ['compound' => true]);

        foreach ($helper->getCheckboxes() as $name => $c) {
            $choices = array_combine(
                array_map(static function ($c, $t) {
                    if (null !== $t) {
                        return $t;
                    }

                    return $c;
                }, $c['choices'], $c['trans']),
                $c['choices']
            );

            $checkboxesBuilder->add($name, ChoiceType::class, [
                'choices' => $choices,
                'expanded' => true,
                'multiple' => true,
            ]);
        }

        if (0 < count($helper->getCheckboxes())) {
            $builder->add($checkboxesBuilder);
        }

        foreach ($this->requestStack->getCurrentRequest()->query->getIterator() as $key => $value) {
            switch ($key) {
                case 'q':
                case 'checkboxes' . $key:
                    break;

                case 'page':
                    $builder->add($key, HiddenType::class, [
                        'data' => 1,
                    ]);

                    break;

                default:
                    $builder->add($key, HiddenType::class, [
                        'data' => $value,
                    ]);

                    break;
            }
        }
    }

    public function buildView(FormView $view, FormInterface $form, array $options)
    {
        /** @var FilterOrderHelper $helper */
        $helper = $options['helper'];
        $view->vars['has_search_box'] = $helper->hasSearchBox();
        $view->vars['checkboxes'] = [];

        foreach ($helper->getCheckboxes() as $name => $c) {
            $view->vars['checkboxes'][$name] = [];
        }
    }

    public function configureOptions(\Symfony\Component\OptionsResolver\OptionsResolver $resolver)
    {
        $resolver->setRequired('helper')
            ->setAllowedTypes('helper', FilterOrderHelper::class);
    }
}
