<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Form\Type;

use Chill\MainBundle\Entity\Civility;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\OptionsResolver\OptionsResolver;

class PickCivilityType extends AbstractType
{
    private TranslatableStringHelper $translatableStringHelper;

    public function __construct(TranslatableStringHelper $translatableStringHelper)
    {
        $this->translatableStringHelper = $translatableStringHelper;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver
            ->setDefault('label', 'Civility')
            ->setDefault(
                'choice_label',
                function (Civility $civility): string {
                    return $this->translatableStringHelper->localize($civility->getName());
                }
            )
            ->setDefault(
                'query_builder',
                static function (EntityRepository $er): QueryBuilder {
                    return $er->createQueryBuilder('c')
                        ->where('c.active = true')
                        ->orderBy('c.order');
                },
            )
            ->setDefault('placeholder', 'choose civility')
            ->setDefault('class', Civility::class);
    }

    public function getParent()
    {
        return EntityType::class;
    }
}
