<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Form;

use Chill\MainBundle\Entity\Location;
use Chill\MainBundle\Repository\LocationRepository;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;

class UserCurrentLocationType extends AbstractType
{
    private LocationRepository $locationRepository;

    private TranslatableStringHelper $translatableStringHelper;

    public function __construct(TranslatableStringHelper $translatableStringHelper, LocationRepository $locationRepository)
    {
        $this->translatableStringHelper = $translatableStringHelper;
        $this->locationRepository = $locationRepository;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('currentLocation', EntityType::class, [
                'class' => Location::class,
                'choices' => $this->locationRepository->findByPublicLocations(),
                'choice_label' => function (Location $entity) {
                    return $entity->getName() ?
                        $entity->getName() . ' (' . $this->translatableStringHelper->localize($entity->getLocationType()->getTitle()) . ')' :
                        $this->translatableStringHelper->localize($entity->getLocationType()->getTitle());
                },
                'placeholder' => 'Pick a location',
                'required' => false,
            ]);
    }
}
