<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Notification\Templating;

use Chill\MainBundle\Entity\NotificationComment;
use Chill\MainBundle\Form\NotificationCommentType;
use Chill\MainBundle\Notification\NotificationPresence;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Twig\Environment;
use Twig\Extension\RuntimeExtensionInterface;

class NotificationTwigExtensionRuntime implements RuntimeExtensionInterface
{
    private FormFactoryInterface $formFactory;

    private NotificationPresence $notificationPresence;

    private UrlGeneratorInterface $urlGenerator;

    public function __construct(FormFactoryInterface $formFactory, NotificationPresence $notificationPresence, UrlGeneratorInterface $urlGenerator)
    {
        $this->formFactory = $formFactory;
        $this->notificationPresence = $notificationPresence;
        $this->urlGenerator = $urlGenerator;
    }

    public function counterNotificationFor(Environment $environment, string $relatedEntityClass, int $relatedEntityId, array $options = []): string
    {
        return $environment->render(
            '@ChillMain/Notification/extension_counter_notifications_for.html.twig',
            [
                'counter' => $this->notificationPresence->countNotificationsForClassAndEntity($relatedEntityClass, $relatedEntityId),
            ]
        );
    }

    public function countNotificationsFor(string $relatedEntityClass, int $relatedEntityId, array $options = []): array
    {
        return $this->notificationPresence->countNotificationsForClassAndEntity($relatedEntityClass, $relatedEntityId);
    }

    public function listNotificationsFor(Environment $environment, string $relatedEntityClass, int $relatedEntityId, array $options = []): string
    {
        $notifications = $this->notificationPresence->getNotificationsForClassAndEntity($relatedEntityClass, $relatedEntityId);

        if ([] === $notifications) {
            return '';
        }

        $appendCommentForms = [];

        foreach ($notifications as $notification) {
            $appendComment = new NotificationComment();
            $appendCommentForms[$notification->getId()] = $this->formFactory->create(
                NotificationCommentType::class,
                $appendComment,
                [
                    'action' => $this->urlGenerator->generate(
                        'chill_main_notification_show',
                        ['id' => $notification->getId()]
                    ),
                ]
            )->createView();
        }

        return $environment->render('@ChillMain/Notification/extension_list_notifications_for.html.twig', [
            'notifications' => $notifications, 'appendCommentForms' => $appendCommentForms,
        ]);
    }
}
