<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Routing\MenuBuilder;

use Chill\MainBundle\Routing\LocalMenuBuilderInterface;
use Chill\MainBundle\Security\Authorization\ChillExportVoter;
use Knp\Menu\MenuItem;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;
use Symfony\Contracts\Translation\TranslatorInterface;

/**
 * Class SectionMenuBuilder.
 */
class SectionMenuBuilder implements LocalMenuBuilderInterface
{
    protected AuthorizationCheckerInterface $authorizationChecker;

    protected ParameterBagInterface $parameterBag;

    protected TranslatorInterface $translator;

    /**
     * SectionMenuBuilder constructor.
     */
    public function __construct(AuthorizationCheckerInterface $authorizationChecker, TranslatorInterface $translator, ParameterBagInterface $parameterBag)
    {
        $this->authorizationChecker = $authorizationChecker;
        $this->translator = $translator;
        $this->parameterBag = $parameterBag;
    }

    /**
     * @param $menuId
     */
    public function buildMenu($menuId, MenuItem $menu, array $parameters)
    {
        $menu->addChild($this->translator->trans('Homepage'), [
            'route' => 'chill_main_homepage',
        ])
            ->setExtras([
                'icons' => ['home'],
                'order' => 0,
            ]);

        if ($this->parameterBag->get('chill_main.access_global_history')) {
            $menu->addChild($this->translator->trans('Global timeline'), [
                'route' => 'chill_center_timeline',
            ])
                ->setExtras(
                    [
                        'order' => 10,
                    ]
                );
        }

        if ($this->authorizationChecker->isGranted(ChillExportVoter::EXPORT)) {
            $menu->addChild($this->translator->trans('Export Menu'), [
                'route' => 'chill_main_export_index',
            ])
                ->setExtras([
                    'icons' => ['upload'],
                    'order' => 20,
                ]);
        }
    }

    public static function getMenuIds(): array
    {
        return ['section'];
    }
}
