<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Security\Authorization;

use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Authorization\Voter\Voter;

use function get_class;
use function in_array;

use const E_USER_DEPRECATED;

/**
 * Voter for Chill software.
 *
 * This abstract Voter provide generic methods to handle object specific to Chill
 */
abstract class AbstractChillVoter extends Voter implements ChillVoterInterface
{
    protected function supports($attribute, $subject)
    {
        @trigger_error(
            'This voter should implements the new `supports` '
            . 'methods introduced by Symfony 3.0, and do not rely on '
            . 'getSupportedAttributes and getSupportedClasses methods.',
            E_USER_DEPRECATED
        );

        // @TODO: getSupportedAttributes() should be created in here and made abstract or in ChillVoterInterface.
        // @TODO: getSupportedClasses() should be created in here and made abstract or in ChillVoterInterface.
        return in_array($attribute, $this->getSupportedAttributes($attribute), true)
            && in_array(get_class($subject), $this->getSupportedClasses(), true);
    }

    protected function voteOnAttribute($attribute, $subject, TokenInterface $token)
    {
        @trigger_error('This voter should implements the new `voteOnAttribute` '
            . 'methods introduced by Symfony 3.0, and do not rely on '
            . 'isGranted method', E_USER_DEPRECATED);

        // @TODO: isGranted() should be created in here and made abstract or in ChillVoterInterface.
        return $this->isGranted($attribute, $subject, $token->getUser());
    }
}
