<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Security\Authorization;

use Chill\MainBundle\Entity\User;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Authorization\Voter\Voter;

class ChillExportVoter extends Voter
{
    public const EXPORT = 'chill_export';

    protected AuthorizationHelperInterface $authorizationHelper;

    public function __construct(AuthorizationHelperInterface $authorizationHelper)
    {
        $this->authorizationHelper = $authorizationHelper;
    }

    protected function supports($attribute, $subject): bool
    {
        return self::EXPORT === $attribute;
    }

    protected function voteOnAttribute($attribute, $subject, TokenInterface $token): bool
    {
        if (!$token->getUser() instanceof User) {
            return false;
        }

        return [] !== $this->authorizationHelper->getReachableCenters($token->getUser(), $attribute);
    }
}
