<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Security\Authorization;

use Chill\MainBundle\Security\Resolver\CenterResolverDispatcherInterface;

final class DefaultVoterHelperGenerator implements VoterGeneratorInterface
{
    private AuthorizationHelper $authorizationHelper;

    private CenterResolverDispatcherInterface $centerResolverDispatcher;

    private array $configuration = [];

    public function __construct(
        AuthorizationHelper $authorizationHelper,
        CenterResolverDispatcherInterface $centerResolverDispatcher
    ) {
        $this->authorizationHelper = $authorizationHelper;
        $this->centerResolverDispatcher = $centerResolverDispatcher;
    }

    public function addCheckFor(?string $subject, array $attributes): self
    {
        $this->configuration[] = [$attributes, $subject];

        return $this;
    }

    public function build(): VoterHelperInterface
    {
        return new DefaultVoterHelper(
            $this->authorizationHelper,
            $this->centerResolverDispatcher,
            $this->configuration
        );
    }
}
