<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Security\PasswordRecover;

use Chill\MainBundle\Entity\User;
use Symfony\Component\EventDispatcher\Event;

class PasswordRecoverEvent extends Event
{
    public const ASK_TOKEN_INVALID_FORM = 'chill_main.ask_token_invalid_form';

    public const ASK_TOKEN_SUCCESS = 'chill_main.ask_token_success';

    public const INVALID_TOKEN = 'chill_main.password_recover_invalid_token';

    /**
     * @var string
     */
    protected $ip;

    /**
     * @var bool
     */
    protected $safelyGenerated;

    /**
     * @var string
     */
    protected $token;

    /**
     * @var User
     */
    protected $user;

    /**
     * @param type $token
     * @param User $user
     * @param type $ip
     * @param bool $safelyGenerated true if generated safely (from console command, etc.)
     */
    public function __construct($token = null, ?User $user = null, $ip = null, bool $safelyGenerated = false)
    {
        $this->user = $user;
        $this->token = $token;
        $this->ip = $ip;
        $this->safelyGenerated = $safelyGenerated;
    }

    public function getIp()
    {
        return $this->ip;
    }

    /**
     * @return string
     */
    public function getToken()
    {
        return $this->token;
    }

    /**
     * @return User|null
     */
    public function getUser()
    {
        return $this->user;
    }

    public function hasIp(): bool
    {
        return !empty($this->ip);
    }

    public function hasUser(): bool
    {
        return $this->user instanceof User;
    }

    public function isSafelyGenerated(): bool
    {
        return $this->safelyGenerated;
    }
}
