<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Security\Resolver;

use Chill\MainBundle\Entity\Center;
use UnexpectedValueException;

use function get_class;
use function is_array;

final class CenterResolverManager implements CenterResolverManagerInterface
{
    /**
     * @var CenterResolverInterface[]
     */
    private iterable $resolvers;

    public function __construct(iterable $resolvers = [])
    {
        $this->resolvers = $resolvers;
    }

    public function resolveCenters($entity, ?array $options = []): array
    {
        foreach ($this->resolvers as $resolver) {
            if ($resolver->supports($entity, $options)) {
                $resolved = $resolver->resolveCenter($entity, $options);

                if (null === $resolved) {
                    return [];
                }

                if ($resolved instanceof Center) {
                    return [$resolved];
                }

                if (is_array($resolved)) {
                    return $resolved;
                }

                throw new UnexpectedValueException(sprintf(
                    'the return type of a %s should be an instance of %s, an array or null. Resolver is %s',
                    CenterResolverInterface::class,
                    Center::class,
                    get_class($resolver)
                ));
            }
        }

        return [];
    }
}
