<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Security\Resolver;

use Chill\MainBundle\Entity\Scope;
use Doctrine\Common\Collections\Collection;

final class ScopeResolverDispatcher
{
    /**
     * @var iterable|ScopeResolverInterface[]
     */
    private iterable $resolvers;

    public function __construct(iterable $resolvers)
    {
        $this->resolvers = $resolvers;
    }

    public function isConcerned($entity, ?array $options = []): bool
    {
        foreach ($this->resolvers as $resolver) {
            if ($resolver->supports($entity, $options)) {
                return $resolver->isConcerned($entity, $options);
            }
        }

        return false;
    }

    /**
     * @param $entity
     *
     * @return iterable|Scope|Scope[]
     */
    public function resolveScope($entity, ?array $options = [])
    {
        foreach ($this->resolvers as $resolver) {
            if ($resolver->supports($entity, $options)) {
                $scopes = $resolver->resolveScope($entity, $options);

                if ($scopes instanceof Collection) {
                    return $scopes->toArray();
                }

                return $scopes;
            }
        }

        return null;
    }
}
