<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Templating\Entity;

use Chill\MainBundle\Entity\User;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Symfony\Component\Templating\EngineInterface;

use function array_merge;

class UserRender implements ChillEntityRenderInterface
{
    public const DEFAULT_OPTIONS = [
        'main_scope' => true,
        'user_job' => true,
    ];

    private EngineInterface $engine;

    private TranslatableStringHelper $translatableStringHelper;

    public function __construct(TranslatableStringHelper $translatableStringHelper, EngineInterface $engine)
    {
        $this->translatableStringHelper = $translatableStringHelper;
        $this->engine = $engine;
    }

    public function renderBox($entity, array $options): string
    {
        $opts = array_merge(self::DEFAULT_OPTIONS, $options);

        return $this->engine->render('@ChillMain/Entity/user.html.twig', [
            'user' => $entity,
            'opts' => $opts,
        ]);
    }

    /**
     * @param User $entity
     */
    public function renderString($entity, array $options): string
    {
        $opts = array_merge(self::DEFAULT_OPTIONS, $options);

        $str = $entity->getLabel();

        if (null !== $entity->getUserJob() && $opts['user_job']) {
            $str .= ' (' . $this->translatableStringHelper
                ->localize($entity->getUserJob()->getLabel()) . ')';
        }

        if (null !== $entity->getMainScope() && $opts['main_scope']) {
            $str .= ' (' . $this->translatableStringHelper
                ->localize($entity->getMainScope()->getName()) . ')';
        }

        return $str;
    }

    public function supports($entity, array $options): bool
    {
        return $entity instanceof User;
    }
}
