<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Templating\Listing;

use Chill\MainBundle\Form\Type\Listing\FilterOrderType;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\HttpFoundation\RequestStack;

use function array_merge;
use function count;

class FilterOrderHelper
{
    private array $checkboxes = [];

    private FormFactoryInterface $formFactory;

    private ?string $formName = 'f';

    private array $formOptions = [];

    private string $formType = FilterOrderType::class;

    private RequestStack $requestStack;

    private ?array $searchBoxFields = null;

    private ?array $submitted = null;

    public function __construct(
        FormFactoryInterface $formFactory,
        RequestStack $requestStack
    ) {
        $this->formFactory = $formFactory;
        $this->requestStack = $requestStack;
    }

    public function addCheckbox(string $name, array $choices, ?array $default = [], ?array $trans = []): self
    {
        $missing = count($choices) - count($trans) - 1;
        $this->checkboxes[$name] = [
            'choices' => $choices, 'default' => $default,
            'trans' => array_merge(
                $trans,
                0 < $missing ?
                       array_fill(0, $missing, null) : []
            ),
        ];

        return $this;
    }

    public function buildForm(): FormInterface
    {
        return $this->formFactory
            ->createNamed($this->formName, $this->formType, $this->getDefaultData(), array_merge([
                'helper' => $this,
                'method' => 'GET',
                'csrf_protection' => false,
            ], $this->formOptions))
            ->handleRequest($this->requestStack->getCurrentRequest());
    }

    public function getCheckboxData(string $name): array
    {
        return $this->getFormData()['checkboxes'][$name];
    }

    public function getCheckboxes(): array
    {
        return $this->checkboxes;
    }

    public function getQueryString(): ?string
    {
        return $this->getFormData()['q'];
    }

    public function hasSearchBox(): bool
    {
        return null !== $this->searchBoxFields;
    }

    public function setSearchBox($searchBoxFields = null): self
    {
        $this->searchBoxFields = $searchBoxFields;

        return $this;
    }

    private function getDefaultData(): array
    {
        $r = [];

        if ($this->hasSearchBox()) {
            $r['q'] = '';
        }

        foreach ($this->checkboxes as $name => $c) {
            $r['checkboxes'][$name] = $c['default'];
        }

        return $r;
    }

    private function getFormData(): array
    {
        if (null === $this->submitted) {
            $this->submitted = $this->buildForm()
                ->getData();
        }

        return $this->submitted;
    }
}
