<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Tests\Controller;

use Chill\MainBundle\Test\PrepareClientTrait;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;
use Symfony\Component\HttpFoundation\Request;
use function array_key_exists;
use function json_decode;

/**
 * @internal
 * @coversNothing
 */
final class UserApiControllerTest extends WebTestCase
{
    use PrepareClientTrait;

    /**
     * @depends testIndex
     *
     * @param mixed $existingUser
     */
    public function testEntity($existingUser)
    {
        $client = $this->getClientAuthenticated();

        $client->request(Request::METHOD_GET, '/api/1.0/main/user/' . $existingUser['id'] . '.json');

        $this->assertResponseIsSuccessful();
    }

    public function testIndex()
    {
        $client = $this->getClientAuthenticated();

        $client->request(Request::METHOD_GET, '/api/1.0/main/user.json');

        $this->assertResponseIsSuccessful();

        $data = json_decode($client->getResponse()->getContent(), true);
        $this->assertTrue(array_key_exists('count', $data));
        $this->assertGreaterThan(0, $data['count']);
        $this->assertTrue(array_key_exists('results', $data));

        return $data['results'][0];
    }

    public function testUserCurrentLocation()
    {
        $client = $this->getClientAuthenticated();

        $client->request(Request::METHOD_GET, '/api/1.0/main/user-current-location.json');

        $this->assertResponseIsSuccessful();
    }

    public function testWhoami()
    {
        $client = $this->getClientAuthenticated();

        $client->request(Request::METHOD_GET, '/api/1.0/main/whoami.json');

        $this->assertResponseIsSuccessful();
    }
}
