<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Workflow\EventSubscriber;

use Chill\MainBundle\Entity\Workflow\EntityWorkflowStep;
use Chill\MainBundle\Workflow\EntityWorkflowManager;
use Chill\MainBundle\Workflow\Helper\MetadataExtractor;
use Symfony\Component\Mailer\MailerInterface;
use Symfony\Component\Mime\Email;
use Symfony\Component\Templating\EngineInterface;
use Symfony\Component\Workflow\Registry;

class SendAccessKeyEventSubscriber
{
    private EngineInterface $engine;

    private EntityWorkflowManager $entityWorkflowManager;

    private MailerInterface $mailer;

    private MetadataExtractor $metadataExtractor;

    private Registry $registry;

    public function __construct(EngineInterface $engine, MetadataExtractor $metadataExtractor, Registry $registry, EntityWorkflowManager $entityWorkflowManager, MailerInterface $mailer)
    {
        $this->engine = $engine;
        $this->metadataExtractor = $metadataExtractor;
        $this->registry = $registry;
        $this->entityWorkflowManager = $entityWorkflowManager;
        $this->mailer = $mailer;
    }

    public function postPersist(EntityWorkflowStep $step): void
    {
        $entityWorkflow = $step->getEntityWorkflow();

        $place = $this->metadataExtractor->buildArrayPresentationForPlace($entityWorkflow);
        $workflow = $this->metadataExtractor->buildArrayPresentationForWorkflow(
            $this->registry->get($entityWorkflow, $entityWorkflow->getWorkflowName())
        );
        $handler = $this->entityWorkflowManager->getHandler($entityWorkflow);

        foreach ($entityWorkflow->futureDestEmails as $emailAddress) {
            $context = [
                'entity_workflow' => $entityWorkflow,
                'dest' => $emailAddress,
                'place' => $place,
                'workflow' => $workflow,
                'entityTitle' => $handler->getEntityTitle($entityWorkflow),
            ];

            $email = new Email();
            $email
                ->addTo($emailAddress)
                ->subject($this->engine->render('@ChillMain/Workflow/workflow_send_access_key_title.fr.txt.twig', $context))
                ->text($this->engine->render('@ChillMain/Workflow/workflow_send_access_key.fr.txt.twig', $context));

            $this->mailer->send($email);
        }
    }
}
