<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\CRUD\Controller;

use BadMethodCallException;
use Chill\MainBundle\CRUD\Controller\CRUDController;
use Chill\PersonBundle\Entity\Person;
use LogicException;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

class OneToOneEntityPersonCRUDController extends CRUDController
{
    protected function generateRedirectOnCreateRoute($action, Request $request, $entity)
    {
        throw new BadMethodCallException('Not implemented yet.');
    }

    protected function getEntity($action, $id, Request $request): ?object
    {
        $entity = parent::getEntity($action, $id, $request);

        if (null === $entity) {
            $entity = $this->createEntity($action, $request);
            $person = $this->getDoctrine()
                ->getManager()
                ->getRepository(Person::class)
                ->find($id);

            $entity->setPerson($person);
        }

        return $entity;
    }

    protected function getTemplateFor($action, $entity, Request $request)
    {
        if (!empty($this->crudConfig[$action]['template'])) {
            return $this->crudConfig[$action]['template'];
        }

        switch ($action) {
            case 'new':
                return '@ChillPerson/CRUD/new.html.twig';

            case 'edit':
                return '@ChillPerson/CRUD/edit.html.twig';

            case 'index':
                return '@ChillPerson/CRUD/index.html.twig';

            default:
                throw new LogicException("the view for action {$action} is not "
                    . 'defined. You should override ' . __METHOD__ . ' to add this '
                    . 'action');
        }
    }

    protected function onPostFetchEntity($action, Request $request, $entity): ?Response
    {
        if (false === $this->getDoctrine()->getManager()->contains($entity)) {
            return new RedirectResponse($this->generateRedirectOnCreateRoute($action, $request, $entity));
        }

        return null;
    }

    protected function onPreFlush(string $action, $entity, FormInterface $form, Request $request)
    {
        $this->getDoctrine()->getManager()->persist($entity);
    }
}
