<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Controller;

use Chill\MainBundle\Pagination\PaginatorFactory;
use Chill\MainBundle\Timeline\TimelineBuilder;
use Chill\PersonBundle\Entity\Person;
use Chill\PersonBundle\Privacy\PrivacyEvent;
use Chill\PersonBundle\Security\Authorization\PersonVoter;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Request;

class TimelinePersonController extends AbstractController
{
    protected EventDispatcherInterface $eventDispatcher;

    protected PaginatorFactory $paginatorFactory;

    protected TimelineBuilder $timelineBuilder;

    public function __construct(
        EventDispatcherInterface $eventDispatcher,
        TimelineBuilder $timelineBuilder,
        PaginatorFactory $paginatorFactory
    ) {
        $this->eventDispatcher = $eventDispatcher;
        $this->timelineBuilder = $timelineBuilder;
        $this->paginatorFactory = $paginatorFactory;
    }

    public function personAction(Request $request, $person_id)
    {
        $person = $this->getDoctrine()
            ->getRepository(Person::class)
            ->find($person_id);

        if (null === $person) {
            throw $this->createNotFoundException();
        }

        $this->denyAccessUnlessGranted(PersonVoter::SEE, $person);

        $nbItems = $this->timelineBuilder->countItems(
            'person',
            ['person' => $person]
        );

        $paginator = $this->paginatorFactory->create($nbItems);

        $event = new PrivacyEvent($person, ['action' => 'timeline']);
        $this->eventDispatcher->dispatch(PrivacyEvent::PERSON_PRIVACY_EVENT, $event);

        return $this->render(
            'ChillPersonBundle:Timeline:index.html.twig',
            [
                'timeline' => $this->timelineBuilder->getTimelineHTML(
                    'person',
                    ['person' => $person],
                    $paginator->getCurrentPage()->getFirstItemNumber(),
                    $paginator->getItemsPerPage()
                ),
                'person' => $person,
                'nb_items' => $nbItems,
                'paginator' => $paginator,
            ]
        );
    }
}
