<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Controller;

use Chill\MainBundle\Pagination\PaginatorFactory;
use Chill\PersonBundle\Repository\AccompanyingPeriodRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;

class UserAccompanyingPeriodController extends AbstractController
{
    private AccompanyingPeriodRepository $accompanyingPeriodRepository;

    private PaginatorFactory $paginatorFactory;

    public function __construct(AccompanyingPeriodRepository $accompanyingPeriodRepository, PaginatorFactory $paginatorFactory)
    {
        $this->accompanyingPeriodRepository = $accompanyingPeriodRepository;
        $this->paginatorFactory = $paginatorFactory;
    }

    /**
     * @Route("/{_locale}/person/accompanying-periods/my", name="chill_person_accompanying_period_user")
     */
    public function listAction(Request $request)
    {
        $total = $this->accompanyingPeriodRepository->countBy(['user' => $this->getUser(), 'step' => ['CONFIRMED', 'CLOSED']]);
        $pagination = $this->paginatorFactory->create($total);
        $accompanyingPeriods = $this->accompanyingPeriodRepository->findBy(
            ['user' => $this->getUser(), 'step' => ['CONFIRMED', 'CLOSED']],
            ['openingDate' => 'DESC'],
            $pagination->getItemsPerPage(),
            $pagination->getCurrentPageFirstItemNumber()
        );

        return $this->render('@ChillPerson/AccompanyingPeriod/user_periods_list.html.twig', [
            'accompanyingPeriods' => $accompanyingPeriods,
            'pagination' => $pagination,
        ]);
    }

    /**
     * @Route("/{_locale}/person/accompanying-periods/my/drafts", name="chill_person_accompanying_period_draft_user")
     */
    public function listDraftsAction(Request $request)
    {
        $total = $this->accompanyingPeriodRepository->countBy(['user' => $this->getUser(), 'step' => 'DRAFT']);
        $pagination = $this->paginatorFactory->create($total);
        $accompanyingPeriods = $this->accompanyingPeriodRepository->findBy(
            ['createdBy' => $this->getUser(), 'step' => 'DRAFT'],
            ['id' => 'DESC'],
            $pagination->getItemsPerPage(),
            $pagination->getCurrentPageFirstItemNumber()
        );

        return $this->render('@ChillPerson/AccompanyingPeriod/user_draft_periods_list.html.twig', [
            'accompanyingPeriods' => $accompanyingPeriods,
            'pagination' => $pagination,
        ]);
    }
}
