<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Entity\AccompanyingPeriod;

use Chill\MainBundle\Doctrine\Model\TrackCreationInterface;
use Chill\MainBundle\Doctrine\Model\TrackCreationTrait;
use Chill\MainBundle\Entity\User;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use DateTimeImmutable;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 * @ORM\Table("chill_person_accompanying_period_user_history")
 */
class UserHistory implements TrackCreationInterface
{
    use TrackCreationTrait;

    /**
     * @ORM\ManyToOne(targetEntity=AccompanyingPeriod::class, inversedBy="userHistories")
     * @ORM\JoinColumn(nullable=false)
     */
    private ?AccompanyingPeriod $accompanyingPeriod;

    /**
     * @ORM\Column(type="datetime_immutable", nullable=true, options={"default": null})
     */
    private ?DateTimeImmutable $endDate = null;

    /**
     * @ORM\Id
     * @ORM\Column(name="id", type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private ?int $id = null;

    /**
     * @ORM\Column(type="datetime_immutable", nullable=false)
     */
    private DateTimeImmutable $startDate;

    /**
     * @ORM\ManyToOne(targetEntity=User::class)
     * @ORM\JoinColumn(nullable=false)
     */
    private User $user;

    public function __construct(AccompanyingPeriod $accompanyingPeriod, User $user, ?DateTimeImmutable $startDate = null)
    {
        $this->startDate = $startDate ?? new DateTimeImmutable('now');
        $this->accompanyingPeriod = $accompanyingPeriod;
        $this->user = $user;
    }

    public function getAccompanyingPeriod(): AccompanyingPeriod
    {
        return $this->accompanyingPeriod;
    }

    public function getEndDate(): ?DateTimeImmutable
    {
        return $this->endDate;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getStartDate(): DateTimeImmutable
    {
        return $this->startDate;
    }

    public function getUser(): User
    {
        return $this->user;
    }

    public function setEndDate(?DateTimeImmutable $endDate): UserHistory
    {
        $this->endDate = $endDate;

        return $this;
    }
}
