<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Export\Aggregator;

use Chill\MainBundle\Export\AggregatorInterface;
use Chill\MainBundle\Export\ExportElementValidatedInterface;
use DateTime;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Validator\Context\ExecutionContextInterface;
use Symfony\Contracts\Translation\TranslatorInterface;

final class AgeAggregator implements AggregatorInterface, ExportElementValidatedInterface
{
    private TranslatorInterface $translator;

    public function __construct(TranslatorInterface $translator)
    {
        $this->translator = $translator;
    }

    public function addRole()
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb->addSelect('DATE_DIFF(:date_age_calculation, person.birthdate)/365 as person_age');
        $qb->setParameter('date_age_calculation', $data['date_age_calculation']);
        $qb->addGroupBy('person_age');
    }

    public function applyOn()
    {
        return 'person';
    }

    public function buildForm(\Symfony\Component\Form\FormBuilderInterface $builder)
    {
        $builder->add('date_age_calculation', DateType::class, [
            'label' => 'Calculate age in relation to this date',
            'data' => new DateTime(),
            'attr' => ['class' => 'datepicker'],
            'widget' => 'single_text',
            'format' => 'dd-MM-yyyy',
        ]);
    }

    public function getLabels($key, array $values, $data)
    {
        return function ($value) {
            if ('_header' === $value) {
                return 'Age';
            }

            if (null === $value) {
                return $this->translator->trans('without data');
            }

            return $value;
        };
    }

    public function getQueryKeys($data)
    {
        return [
            'person_age',
        ];
    }

    public function getTitle()
    {
        return 'Aggregate by age';
    }

    public function validateForm($data, ExecutionContextInterface $context)
    {
        if (null === $data['date_age_calculation']) {
            $context->buildViolation('The date should not be empty')
                ->addViolation();
        }
    }
}
