<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Export\Filter;

use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Form\Type\ChillDateType;
use Chill\PersonBundle\Export\AbstractAccompanyingPeriodExportElement;
use DateTime;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\FormBuilderInterface;

class AccompanyingPeriodOpeningFilter extends AbstractAccompanyingPeriodExportElement implements FilterInterface
{
    public function addRole()
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $this->addJoinAccompanyingPeriod($qb);

        $clause = $qb->expr()->andX(
            $qb->expr()->lte('accompanying_period.openingDate', ':date_to'),
            $qb->expr()->gte('accompanying_period.openingDate', ':date_from')
        );

        $qb->andWhere($clause);
        $qb->setParameter('date_from', $data['date_from'], Types::DATE_MUTABLE);
        $qb->setParameter('date_to', $data['date_to'], Types::DATE_MUTABLE);
    }

    public function applyOn(): string
    {
        return 'person';
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('date_from', ChillDateType::class, [
            'label' => 'Having an accompanying period opened after this date',
            'data' => new DateTime('-1 month'),
        ]);

        $builder->add('date_to', ChillDateType::class, [
            'label' => 'Having an accompanying period opened before this date',
            'data' => new DateTime(),
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        return [
            'Filtered by accompanying period: persons having an accompanying period'
            . ' opened between the %date_from% and %date_to%',
            [
                '%date_from%' => $data['date_from']->format('d-m-Y'),
                '%date_to%' => $data['date_to']->format('d-m-Y'),
            ],
        ];
    }

    public function getTitle(): string
    {
        return 'Filter by accompanying period: starting between two dates';
    }
}
