<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Form\SocialWork;

use Chill\MainBundle\Form\Type\TranslatableStringFormType;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Entity\SocialWork\SocialAction;
use Chill\PersonBundle\Entity\SocialWork\SocialIssue;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * Class SocialActionType.
 */
class SocialActionType extends AbstractType
{
    /**
     * @var TranslatableStringHelper
     */
    protected $translatableStringHelper;

    public function __construct(TranslatableStringHelper $translatableStringHelper)
    {
        $this->translatableStringHelper = $translatableStringHelper;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('title', TranslatableStringFormType::class, [
                'label' => 'Nom',
            ])
            ->add('issue', EntityType::class, [
                'class' => SocialIssue::class,
                'choice_label' => function (SocialIssue $issue) {
                    return $this->translatableStringHelper->localize($issue->getTitle());
                },
            ])
            ->add('parent', EntityType::class, [
                'class' => SocialAction::class,
                'required' => false,
                'choice_label' => function (SocialAction $issue) {
                    return $this->translatableStringHelper->localize($issue->getTitle());
                },
            ])
            ->add('defaultNotificationDelay')
            ->add('desactivationDate', DateType::class, [
                'attr' => ['class' => 'datepicker'],
                'widget' => 'single_text',
                'format' => 'dd-MM-yyyy',
                'required' => false,
            ]);
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver
            ->setDefault('class', SocialIssue::class);
    }
}
