<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Notification;

use Chill\MainBundle\Entity\Notification;
use Chill\MainBundle\Notification\NotificationHandlerInterface;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\PersonBundle\Repository\AccompanyingPeriodRepository;

final class AccompanyingPeriodNotificationHandler implements NotificationHandlerInterface
{
    private AccompanyingPeriodRepository $accompanyingPeriodRepository;

    public function __construct(AccompanyingPeriodRepository $accompanyingPeriodRepository)
    {
        $this->accompanyingPeriodRepository = $accompanyingPeriodRepository;
    }

    public function getTemplate(Notification $notification, array $options = []): string
    {
        return 'ChillPersonBundle:AccompanyingPeriod:showInNotification.html.twig';
    }

    public function getTemplateData(Notification $notification, array $options = []): array
    {
        return [
            'notification' => $notification,
            'period' => $this->accompanyingPeriodRepository->find($notification->getRelatedEntityId()),
        ];
    }

    public function supports(Notification $notification, array $options = []): bool
    {
        return $notification->getRelatedEntityClass() === AccompanyingPeriod::class;
    }
}
