<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Privacy;

/*
 * Chill is a software for social workers
 *
 * Copyright (C) 2014-2015, Champs Libres Cooperative SCRLFS,
 * <http://www.champs-libres.coop>, <info@champs-libres.coop>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

use Chill\PersonBundle\Entity\Person;
use Psr\Log\LoggerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

use function array_map;

class PrivacyEventSubscriber implements EventSubscriberInterface
{
    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var TokenStorageInterface
     */
    protected $token;

    /**
     * PrivacyEventSubscriber constructor.
     */
    public function __construct(LoggerInterface $logger, TokenStorageInterface $token)
    {
        $this->logger = $logger;
        $this->token = $token;
    }

    public static function getSubscribedEvents()
    {
        return [
            PrivacyEvent::PERSON_PRIVACY_EVENT => [
                ['onPrivacyEvent'],
            ],
            AccompanyingPeriodPrivacyEvent::ACCOMPANYING_PERIOD_PRIVACY_EVENT => [
                ['onAccompanyingPeriodPrivacyEvent'],
            ],
        ];
    }

    public function onAccompanyingPeriodPrivacyEvent(AccompanyingPeriodPrivacyEvent $event)
    {
        $involved = $this->getInvolved();
        $involved['period_id'] = $event->getPeriod()->getId();
        $involved['persons'] = $event->getPeriod()->getPersons()
            ->map(static function (Person $p) {
                return $p->getId();
            })
            ->toArray();

        $this->logger->notice(
            '[Privacy Event] An accompanying period has been viewed',
            array_merge($involved, $event->getArgs())
        );
    }

    public function onPrivacyEvent(PrivacyEvent $event)
    {
        $persons = [];

        if ($event->hasPersons() === true) {
            foreach ($event->getPersons() as $person) {
                $persons[] = $person->getId();
            }
        }

        $involved = $this->getInvolved();
        $involved['person_id'] = $event->getPerson()->getId();

        if ($event->hasPersons()) {
            $involved['persons'] = array_map(
                static function (Person $p) {
                    return $p->getId();
                },
                $event->getPersons()
            );
        }

        $this->logger->notice(
            '[Privacy Event] A Person Folder has been viewed',
            array_merge($involved, $event->getArgs())
        );
    }

    protected function getInvolved(): array
    {
        return [
            'by_user' => $this->token->getToken()->getUser()->getUsername(),
            'by_user_id' => $this->token->getToken()->getUser()->getId(),
        ];
    }
}
