<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Repository\AccompanyingPeriod;

use Chill\PersonBundle\Entity\AccompanyingPeriod\ClosingMotive;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\ResultSetMappingBuilder;

final class ClosingMotiveRepository
{
    private EntityManagerInterface $entityManager;

    private EntityRepository $repository;

    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->entityManager = $entityManager;
        $this->repository = $entityManager->getRepository(ClosingMotive::class);
    }

    /**
     * @return mixed
     */
    public function getActiveClosingMotive(bool $onlyLeaf = true)
    {
        $rsm = new ResultSetMappingBuilder($this->entityManager);
        $rsm->addRootEntityFromClassMetadata($this->repository->getClassName(), 'cm');

        $sql = 'SELECT ' . (string) $rsm . '
            FROM chill_person_accompanying_period_closingmotive AS cm
            WHERE
                active IS TRUE ';

        if ($onlyLeaf) {
            $sql .= 'AND cm.id NOT IN (
                SELECT DISTINCT parent_id FROM chill_person_accompanying_period_closingmotive WHERE parent_id IS NOT NULL
            )';
        }

        $sql .= ' ORDER BY cm.ordering ASC';

        return $this
            ->entityManager
            ->createNativeQuery($sql, $rsm)
            ->getResult();
    }
}
