<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Templating\Entity;

use Chill\MainBundle\Templating\Entity\AbstractChillEntityRender;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Entity\AccompanyingPeriod\ClosingMotive;

/**
 * Render closing motive.
 */
class ClosingMotiveRender extends AbstractChillEntityRender
{
    private const SEPARATOR = ' > ';

    /**
     * @var TranslatableStringHelper
     */
    private $translatableStringHelper;

    public function __construct(TranslatableStringHelper $translatableStringHelper)
    {
        $this->translatableStringHelper = $translatableStringHelper;
    }

    public function renderBox($entity, array $options): string
    {
        return
            $this->getDefaultOpeningBox('closing-motive') .
            $this->renderString($entity, $options) .
            $this->getDefaultClosingBox();
    }

    /**
     * @param ClosingMotive $entity
     */
    public function renderString($entity, array $options): string
    {
        return $this->renderStringRecursive(
            $entity,
            '', //$this->translatableStringHelper->localize($entity->getName()),
            $options
        );
    }

    public function supports($entity, array $options): bool
    {
        return $entity instanceof ClosingMotive;
    }

    protected function renderStringRecursive(ClosingMotive $motive, $existing, array $options)
    {
        $newExisting = $this->translatableStringHelper->localize($motive->getName());

        if ($motive->hasParent()) {
            if (!empty($existing)) {
                $newExisting = $newExisting . self::SEPARATOR . $existing;
            }

            return $this->renderStringRecursive(
                $motive->getParent(),
                $newExisting,
                $options
            );
        }

        if (!empty($existing)) {
            return $newExisting . self::SEPARATOR . $existing;
        }

        return $newExisting;
    }
}
