<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Templating\Entity;

use Chill\MainBundle\Templating\Entity\ChillEntityRenderInterface;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Entity\SocialWork\SocialIssue;
use Symfony\Component\Templating\EngineInterface;

use function array_reverse;
use function implode;

final class SocialIssueRender implements ChillEntityRenderInterface
{
    public const DEFAULT_ARGS = [
        self::SEPARATOR_KEY => ' > ',
    ];

    public const SEPARATOR_KEY = 'default.separator';

    private EngineInterface $engine;

    private TranslatableStringHelper $translatableStringHelper;

    public function __construct(TranslatableStringHelper $translatableStringHelper, EngineInterface $engine)
    {
        $this->translatableStringHelper = $translatableStringHelper;
        $this->engine = $engine;
    }

    /**
     * @param SocialIssue $socialIssue
     */
    public function renderBox($socialIssue, array $options): string
    {
        $options = array_merge(self::DEFAULT_ARGS, $options);
        // give some help to twig: an array of parents
        $parents = $this->buildParents($socialIssue);

        return $this
            ->engine
            ->render(
                '@ChillPerson/Entity/social_issue.html.twig',
                [
                    'socialIssue' => $socialIssue,
                    'parents' => $parents,
                    'options' => $options,
                ]
            );
    }

    /**
     * @param SocialIssue $socialIssue
     */
    public function renderString($socialIssue, array $options): string
    {
        /** @var SocialIssue $socialIssue */
        $options = array_merge(self::DEFAULT_ARGS, $options);

        $titles = [$this->translatableStringHelper->localize($socialIssue->getTitle())];

        // loop to parent, until root
        while ($socialIssue->hasParent()) {
            $socialIssue = $socialIssue->getParent();
            $titles[] = $this->translatableStringHelper->localize(
                $socialIssue->getTitle()
            );
        }

        $titles = array_reverse($titles);

        return implode($options[self::SEPARATOR_KEY], $titles);
    }

    public function supports($entity, array $options): bool
    {
        return $entity instanceof SocialIssue;
    }

    private function buildParents(SocialIssue $socialIssue): array
    {
        $parents = [];

        while ($socialIssue->hasParent()) {
            $socialIssue = $parents[] = $socialIssue->getParent();
        }

        return $parents;
    }
}
