<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Tests\AccompanyingPeriod\SocialIssueConsistency;

use Chill\PersonBundle\AccompanyingPeriod\SocialIssueConsistency\AccompanyingPeriodLinkedWithSocialIssuesEntityInterface;
use Chill\PersonBundle\AccompanyingPeriod\SocialIssueConsistency\AccompanyingPeriodSocialIssueConsistencyEntityListener;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\PersonBundle\Entity\SocialWork\SocialIssue;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Event\LifecycleEventArgs;
use PHPUnit\Framework\TestCase;

/**
 * @internal
 * @coversNothing
 */
final class AccompanyingPeriodSocialIssueConsistencyEntityListenerTest extends TestCase
{
    public function testPrePersist()
    {
        $socialIssues = new ArrayCollection([
            $parent = new SocialIssue(),
            $child = (new SocialIssue())->setParent($parent),
            $grandChild = (new SocialIssue())->setParent($child),
            $grandGrandChild = (new SocialIssue())->setParent($grandChild),
        ]);
        $period = (new AccompanyingPeriod())->addSocialIssue($unrelated = new SocialIssue());
        $entity = $this->generateClass($period, $socialIssues);
        $consistency = new AccompanyingPeriodSocialIssueConsistencyEntityListener();

        $consistency->prePersist($entity, $this->generateLifecycleArgs());

        $this->assertCount(2, $period->getSocialIssues());
        $this->assertContains($grandGrandChild, $period->getSocialIssues());
        $this->assertContains($unrelated, $period->getSocialIssues());

        $this->assertCount(1, $entity->getSocialIssues());
        $this->assertContains($grandGrandChild, $entity->getSocialIssues());
    }

    public function testPrePersistAccompanyingPeriod()
    {
        $arraySocialIssues = [
            $parent = new SocialIssue(),
            $child = (new SocialIssue())->setParent($parent),
            $grandChild = (new SocialIssue())->setParent($child),
            $grandGrandChild = (new SocialIssue())->setParent($grandChild),
        ];
        $period = new AccompanyingPeriod();
        $consistency = new AccompanyingPeriodSocialIssueConsistencyEntityListener();

        foreach ($arraySocialIssues as $issue) {
            $period->addSocialIssue($issue);
        }

        $consistency->prePersistAccompanyingPeriod($period, $this->generateLifecycleArgs());

        $this->assertCount(1, $period->getSocialIssues());
        $this->assertSame($grandGrandChild, $period->getSocialIssues()->first());
    }

    public function testPreUpdate()
    {
        $socialIssues = new ArrayCollection([
            $parent = new SocialIssue(),
            $child = (new SocialIssue())->setParent($parent),
            $grandChild = (new SocialIssue())->setParent($child),
            $grandGrandChild = (new SocialIssue())->setParent($grandChild),
        ]);
        $period = (new AccompanyingPeriod())->addSocialIssue($unrelated = new SocialIssue());
        $entity = $this->generateClass($period, $socialIssues);
        $consistency = new AccompanyingPeriodSocialIssueConsistencyEntityListener();

        $consistency->preUpdate($entity, $this->generateLifecycleArgs());

        $this->assertCount(2, $period->getSocialIssues());
        $this->assertContains($grandGrandChild, $period->getSocialIssues());
        $this->assertContains($unrelated, $period->getSocialIssues());

        $this->assertCount(1, $entity->getSocialIssues());
        $this->assertContains($grandGrandChild, $entity->getSocialIssues());
    }

    public function testPreUpdateAccompanyingPeriod()
    {
        $arraySocialIssues = [
            $parent = new SocialIssue(),
            $child = (new SocialIssue())->setParent($parent),
            $grandChild = (new SocialIssue())->setParent($child),
            $grandGrandChild = (new SocialIssue())->setParent($grandChild),
        ];
        $period = new AccompanyingPeriod();
        $consistency = new AccompanyingPeriodSocialIssueConsistencyEntityListener();

        foreach ($arraySocialIssues as $issue) {
            $period->addSocialIssue($issue);
        }

        $consistency->prePersistAccompanyingPeriod($period, $this->generateLifecycleArgs());

        $this->assertCount(1, $period->getSocialIssues());
        $this->assertSame($grandGrandChild, $period->getSocialIssues()->first());
    }

    protected function generateClass(AccompanyingPeriod $period, Collection $socialIssues): AccompanyingPeriodLinkedWithSocialIssuesEntityInterface
    {
        return new class($period, $socialIssues) implements AccompanyingPeriodLinkedWithSocialIssuesEntityInterface {
            public Collection $socialIssues;

            public AccompanyingPeriod $period;

            public function __construct($period, $socialIssues)
            {
                $this->period = $period;
                $this->socialIssues = $socialIssues;
            }

            public function getAccompanyingPeriod(): AccompanyingPeriod
            {
                return $this->period;
            }

            public function getSocialIssues(): Collection
            {
                return $this->socialIssues;
            }

            public function removeSocialIssue(SocialIssue $issue): AccompanyingPeriodLinkedWithSocialIssuesEntityInterface
            {
                $this->socialIssues->removeElement($issue);

                return $this;
            }
        };
    }

    protected function generateLifecycleArgs(): LifecycleEventArgs
    {
        return $this->createMock(LifecycleEventArgs::class);
    }
}
