<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

use Chill\PersonBundle\Entity\Person;
use Chill\PersonBundle\Entity\PersonAltName;
use Chill\PersonBundle\EventListener\PersonEventListener;
use PHPUnit\Framework\TestCase;

/**
 * @internal
 * @coversNothing
 */
final class PersonCreateEventTest extends TestCase
{
    public function generateAltNames(): iterator
    {
        yield ['vinCENT', 'VINCENT'];

        yield ['jean-marie', 'JEAN-MARIE'];

        yield ['fastré', 'FASTRÉ'];

        yield ['émile', 'ÉMILE'];
    }

    public function generateNames(): iterator
    {
        yield ['émelie-marie', 'Émelie-Marie', 'lenaerts', 'LENAERTS'];

        yield ['jean-marie', 'Jean-Marie', 'lenaerts', 'LENAERTS'];

        yield ['vinCENT', 'Vincent', 'fastré', 'FASTRÉ'];

        yield ['Vincent', 'Vincent', 'van Gogh', 'VAN GOGH'];

        yield ['André marie', 'André Marie', 'Bah', 'BAH'];
    }

    /**
     * @dataProvider generateAltNames
     *
     * @param mixed $altname
     * @param mixed $altnameExpected
     */
    public function testAltNamesOnPrePersist($altname, $altnameExpected)
    {
        $listener = new PersonEventListener();

        $personAltname = new PersonAltName();

        $personAltname->setLabel($altname);

        $listener->prePersistAltName($personAltname);

        $this->assertEquals($altnameExpected, $personAltname->getLabel());
    }

    /**
     * @dataProvider generateNames
     *
     * @param mixed $firstname
     * @param mixed $firstnameExpected
     * @param mixed $lastname
     * @param mixed $lastnameExpected
     */
    public function testOnPrePersist($firstname, $firstnameExpected, $lastname, $lastnameExpected)
    {
        $listener = new PersonEventListener();

        $person = new Person();

        $person->setFirstName($firstname);
        $person->setLastName($lastname);

        $listener->prePersistPerson($person);

        $this->assertEquals($firstnameExpected, $person->getFirstName());
        $this->assertEquals($lastnameExpected, $person->getLastName());
    }
}
