<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Tests\Export\Filter;

use Chill\MainBundle\Test\Export\AbstractFilterTest;
use DateTime;
use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;

/**
 * @internal
 * @coversNothing
 */
final class AccompanyingPeriodFilterTest extends AbstractFilterTest
{
    /**
     * @var \Chill\PersonBundle\Export\Filter\BirthdateFilter
     */
    private $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        try {
            $this->filter = self::$container->get('chill.person.export.filter_accompanying_period');
        } catch (ServiceNotFoundException $e) {
            $this->markTestSkipped('The current configuration does not use accompanying_periods');
        }
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData()
    {
        return [
            [
                'date_from' => DateTime::createFromFormat('Y-m-d', '2000-01-01'),
                'date_to' => DateTime::createFromFormat('Y-m-d', '2010-01-01'),
            ],
        ];
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('person.firstName')
                ->from('ChillPersonBundle:Person', 'person'),
            $em->createQueryBuilder()
                ->select('person.firstName')
                ->from('ChillPersonBundle:Person', 'person')
                // add a dummy where clause
                ->where('person.firstname IS NOT NULL'),
            $em->createQueryBuilder()
                ->select('count(IDENTITY(p))')
                ->from('ChillPersonBundle:Person', 'person')
                // add a dummy where clause
                ->where('person.firstname IS NOT NULL'),
            $em->createQueryBuilder()
                ->select('count(IDENTITY(p))')
                ->from('ChillPersonBundle:Person', 'person')
                ->join('person.accompanyingPeriods', 'accompanying_period')
                // add a dummy where clause
                ->where('person.firstname IS NOT NULL'),
            $em->createQueryBuilder()
                ->select('activity.date AS date')
                ->select('activity.attendee as attendee')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.person', 'person')
                ->join('person.center', 'center'),
        ];
    }
}
