<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Tests\Export\Filter;

use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Chill\PersonBundle\Entity\Person;

/**
 * @internal
 * @coversNothing
 */
final class GenderFilterTest extends AbstractFilterTest
{
    /**
     * @var \Chill\PersonBundle\Export\Filter\GenderFilter
     */
    private $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        // add a fake request with a default locale (used in translatable string)
        $prophet = new \Prophecy\Prophet();
        $request = $prophet->prophesize();
        $request->willExtend(\Symfony\Component\HttpFoundation\Request::class);
        $request->getLocale()->willReturn('fr');

        $this->filter = self::$container->get('chill.person.export.filter_gender');
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData()
    {
        return [
            [
                'accepted_genders' => [Person::FEMALE_GENDER],
            ],
            [
                'accepted_genders' => [Person::MALE_GENDER],
            ],
            [
                'accepted_genders' => [Person::MALE_GENDER, Person::BOTH_GENDER],
            ],
        ];
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('p.firstName')
                ->from('ChillPersonBundle:Person', 'p'),
        ];
    }
}
