<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Tests\Validator\Person;

use Chill\PersonBundle\Validator\Constraints\Person\Birthdate;
use Chill\PersonBundle\Validator\Constraints\Person\BirthdateValidator;
use DateTime;
use Symfony\Component\Validator\Test\ConstraintValidatorTestCase;

/**
 * Test the behaviour of BirthdayValidator.
 *
 * @internal
 * @coversNothing
 */
final class BirthdateValidatorTest extends ConstraintValidatorTestCase
{
    public function testTomorrowInvalid()
    {
        $bornAfter = new DateTime('+2 days');
        $this->validator->validate($bornAfter, $this->createConstraint());
        $this->buildViolation('msg')
            ->setParameter('%date%', (new DateTime('yesterday'))->format('d-m-Y'))
            ->setCode('3f42fd96-0b2d-11ec-8cf3-0f3b1b1ca1c4')
            ->assertRaised();
    }

    public function testValidateTodayInvalid()
    {
        $bornToday = new DateTime('now');
        $this->validator->validate($bornToday, $this->createConstraint());
        $this->buildViolation('msg')
            ->setParameter('%date%', (new DateTime('yesterday'))->format('d-m-Y'))
            ->setCode('3f42fd96-0b2d-11ec-8cf3-0f3b1b1ca1c4')
            ->assertRaised();
    }

    public function testValidateYesterdayValid()
    {
        $bornYesterday = new DateTime('yesterday');
        $this->validator->validate($bornYesterday, $this->createConstraint());
        $this->assertNoViolation();
    }

    protected function createValidator()
    {
        return new BirthdateValidator('P1D');
    }

    private function createConstraint()
    {
        return new Birthdate([
            'message' => 'msg',
        ]);
    }
}
