<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\ReportBundle\Export\Filter;

use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Form\Type\ChillDateType;
use DateTime;
use Doctrine\ORM\Query\Expr;

class ReportDateFilter implements FilterInterface
{
    public function addRole()
    {
        return null;
    }

    public function alterQuery(\Doctrine\ORM\QueryBuilder $qb, $data)
    {
        $where = $qb->getDQLPart('where');
        $clause = $qb->expr()->between(
            'report.date',
            ':report_date_filter_date_from',
            ':report_date_filter_date_to'
        );

        if ($where instanceof Expr\Andx) {
            $where->add($clause);
        } else {
            $where = $qb->expr()->andX($clause);
        }

        $qb->add('where', $where);
        $qb->setParameter('report_date_filter_date_from', $data['date_from']);
        $qb->setParameter('report_date_filter_date_to', $data['date_to']);
    }

    public function applyOn()
    {
        return 'report';
    }

    public function buildForm(\Symfony\Component\Form\FormBuilderInterface $builder)
    {
        $builder->add('date_from', ChillDateType::class, [
            'label' => 'Report is after this date',
            'data' => new DateTime(),
        ]);

        $builder->add('date_to', ChillDateType::class, [
            'label' => 'Report is before this date',
            'data' => new DateTime(),
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        return ['Filtered by report\'s date: '
            . 'between %date_from% and %date_to%', [
                '%date_from%' => $data['date_from']->format('d-m-Y'),
                '%date_to%' => $data['date_to']->format('d-m-Y'),
            ], ];
    }

    public function getTitle()
    {
        return 'Filter by report\'s date';
    }
}
