<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\TaskBundle\Entity\Task;

use Chill\MainBundle\Entity\User;
use DateTimeImmutable;
use Doctrine\ORM\Mapping as ORM;

/**
 * AbstractTaskPlaceEvent.
 *
 * @ORM\MappedSuperclass
 */
class AbstractTaskPlaceEvent
{
    /**
     * @var User
     * @ORM\ManyToOne(
     *     targetEntity="\Chill\MainBundle\Entity\User"
     * )
     */
    private $author;

    /**
     * @var string
     *
     * @ORM\Column(name="data", type="json")
     */
    private $data = [];

    /**
     * @var datetime_immutable
     *
     * @ORM\Column(name="datetime", type="datetime_immutable")
     */
    private $datetime;

    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="transition", type="string", length=255)
     */
    private $transition = '';

    public function __construct()
    {
        $this->datetime = new DateTimeImmutable('now');
    }

    public function getAuthor(): User
    {
        return $this->author;
    }

    /**
     * Get data.
     *
     * @return string
     */
    public function getData()
    {
        return $this->data;
    }

    /**
     * Get datetime.
     *
     * @return datetime_immutable
     */
    public function getDatetime()
    {
        return $this->datetime;
    }

    /**
     * Get id.
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Get transition.
     *
     * @return string
     */
    public function getTransition()
    {
        return $this->transition;
    }

    public function setAuthor(User $author)
    {
        $this->author = $author;

        return $this;
    }

    /**
     * Set data.
     *
     * @param string $data
     *
     * @return AbstractTaskPlaceEvent
     */
    public function setData($data)
    {
        $this->data = $data;

        return $this;
    }

    /**
     * Set datetime.
     *
     * @param datetime_immutable $datetime
     *
     * @return AbstractTaskPlaceEvent
     */
    public function setDatetime($datetime)
    {
        $this->datetime = $datetime;

        return $this;
    }

    /**
     * Set transition.
     *
     * @param string $transition
     *
     * @return AbstractTaskPlaceEvent
     */
    public function setTransition($transition)
    {
        $this->transition = $transition;

        return $this;
    }
}
