<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\TaskBundle\Event\UI;

use Chill\TaskBundle\Entity\AbstractTask;
use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Workflow\Transition;

class UIEvent extends Event
{
    public const EDIT_FORM = 'chill_task.edit_form';

    public const EDIT_PAGE = 'chill_task.edit_page';

    public const SHOW_TRANSITION_PAGE = 'chill_task.show_transition_page';

    /**
     * @var FormInterface|null
     */
    protected $form;

    /**
     * @var string
     */
    protected $kind;

    /**
     * @var Response|null
     */
    protected $response;

    /**
     * @var AbstractTask
     */
    protected $task;

    /**
     * @var Transition
     */
    protected $transition;

    public function __construct($kind, AbstractTask $task)
    {
        $this->kind = $kind;
        $this->task = $task;
    }

    /**
     * @return FormInterface|null
     */
    public function getForm()
    {
        return $this->form;
    }

    /**
     * @return string
     */
    public function getKind()
    {
        return $this->kind;
    }

    public function getResponse(): Response
    {
        return $this->response;
    }

    public function getTask(): AbstractTask
    {
        return $this->task;
    }

    /**
     * @return Transition
     */
    public function getTransition()
    {
        return $this->transition;
    }

    public function hasResponse()
    {
        return $this->response instanceof Response;
    }

    public function setForm(FormInterface $form)
    {
        $this->form = $form;

        return $this;
    }

    /**
     * @return $this
     */
    public function setResponse(Response $response)
    {
        $this->response = $response;

        return $this;
    }

    public function setTransition(Transition $transition)
    {
        $this->transition = $transition;

        return $this;
    }
}
