<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Symfony\Component\DependencyInjection\Loader\Configurator;

use ChampsLibres\AsyncUploaderBundle\TempUrl\TempUrlGeneratorInterface;
use ChampsLibres\WopiBundle\Service\Wopi as CLWopi;
use ChampsLibres\WopiLib\Contract\Service\DocumentManagerInterface;
use Chill\WopiBundle\Service\Wopi\ChillDocumentManager;
use Chill\WopiBundle\Service\Wopi\ChillWopi;

return static function (ContainerConfigurator $container) {
    $services = $container
        ->services();

    $services
        ->defaults()
        ->autowire()
        ->autoconfigure();

    $services
        ->load('Chill\\WopiBundle\\Service\\', __DIR__ . '/../../Service');

    $services
        ->load('Chill\\WopiBundle\\Controller\\', __DIR__ . '/../../Controller')
        ->tag('controller.service_arguments');

    $services
        ->set(ChillWopi::class)
        ->decorate(CLWopi::class)
        ->arg('$wopi', service('.inner'));

    $services
        ->alias(DocumentManagerInterface::class, ChillDocumentManager::class);

    // TODO: Move this into the async bundle (low priority)
    $services
        ->alias(TempUrlGeneratorInterface::class, 'async_uploader.temp_url_generator');
};
